@@ -9,6 +9,6 @@ with urlopen("http://download.redis.io/redis-stable.tar.gz") as in_stream, open(
     "redis-stable.tar.gz", "wb"
 ) as out_file:
     copyfileobj(in_stream, out_file)
-tar = tarfile.open("redis-stable.tar.gz")
-tar.extractall()
+with tarfile.open("redis-stable.tar.gz") as tar:
+    tar.extractall()
 subprocess.run("make", cwd="redis-stable")
